@@ -32,15 +32,16 @@
 /**
  * SECTION:dh-book-tree
  * @Title: DhBookTree
- * @Short_description: A #GtkTreeView containing the tree structure of all
- * enabled #DhBook's
+ * @Short_description: A #GtkTreeView containing the tree structure of a
+ * #DhBookList
  *
  * #DhBookTree is a #GtkTreeView (showing a tree, not a list) containing the
- * general tree structure of all enabled #DhBook's.
+ * general tree structure of the #DhBook's contained in a #DhBookList (the
+ * #DhBookList part of the provided #DhProfile).
  *
- * The dh_book_get_tree() function is called to get the tree structure of a
- * #DhBook. As such the tree contains only #DhLink's of type %DH_LINK_TYPE_BOOK
- * or %DH_LINK_TYPE_PAGE.
+ * #DhBookTree calls the dh_book_get_tree() function to get the tree structure
+ * of a #DhBook. As such the tree contains only #DhLink's of type
+ * %DH_LINK_TYPE_BOOK or %DH_LINK_TYPE_PAGE.
  *
  * When an element is selected, the #DhBookTree::link-selected signal is
  * emitted. Only one element can be selected at a time.
@@ -106,7 +107,9 @@ book_tree_selection_changed_cb (GtkTreeSelection *selection,
 
         if (link != NULL &&
             link != priv->selected_link) {
-                g_clear_pointer (&priv->selected_link, (GDestroyNotify)dh_link_unref);
+                if (priv->selected_link != NULL)
+                        dh_link_unref (priv->selected_link);
+
                 priv->selected_link = dh_link_ref (link);
                 g_signal_emit (tree, signals[LINK_SELECTED], 0, link);
         }
@@ -581,7 +584,9 @@ book_tree_init_selection (DhBookTree *tree)
                 if (link == NULL || dh_link_get_link_type (link) != DH_LINK_TYPE_BOOK)
                         g_warn_if_reached ();
 
-                g_clear_pointer (&priv->selected_link, (GDestroyNotify)dh_link_unref);
+                if (priv->selected_link != NULL)
+                        dh_link_unref (priv->selected_link);
+
                 priv->selected_link = link;
                 gtk_tree_selection_select_iter (selection, &iter);
         }
@@ -718,9 +723,13 @@ dh_book_tree_dispose (GObject *object)
 
         g_clear_object (&priv->profile);
         g_clear_object (&priv->store);
-        g_clear_pointer (&priv->selected_link, (GDestroyNotify)dh_link_unref);
         priv->context_menu = NULL;
 
+        if (priv->selected_link != NULL) {
+                dh_link_unref (priv->selected_link);
+                priv->selected_link = NULL;
+        }
+
         G_OBJECT_CLASS (dh_book_tree_parent_class)->dispose (object);
 }
 
