@@ -31,7 +31,7 @@
 
 typedef struct {
         GtkHeaderBar *header_bar;
-        GtkMenuButton *window_menu_button;
+        GtkMenuButton *menu_button;
 
         DhSidebar *sidebar;
         DhSearchBar *search_bar;
@@ -62,7 +62,7 @@ dh_window_dispose (GObject *object)
         DhWindowPrivate *priv = dh_window_get_instance_private (DH_WINDOW (object));
 
         priv->header_bar = NULL;
-        priv->window_menu_button = NULL;
+        priv->menu_button = NULL;
         priv->sidebar = NULL;
         priv->search_bar = NULL;
         priv->notebook = NULL;
@@ -461,45 +461,14 @@ add_actions (DhWindow *window)
         g_object_unref (property_action);
 
         property_action = g_property_action_new ("show-window-menu",
-                                                 priv->window_menu_button,
+                                                 priv->menu_button,
                                                  "active");
         g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (property_action));
         g_object_unref (property_action);
 }
 
 static GMenuModel *
-create_window_menu_simple (void)
-{
-        GMenu *menu;
-        GMenu *section;
-        AmtkFactory *factory;
-
-        menu = g_menu_new ();
-        factory = amtk_factory_new (NULL);
-
-        section = g_menu_new ();
-        amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "win.show-sidebar"));
-        amtk_gmenu_append_section (menu, NULL, section);
-
-        section = g_menu_new ();
-        amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "win.print"));
-        amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "win.find"));
-        amtk_gmenu_append_section (menu, NULL, section);
-
-        section = g_menu_new ();
-        amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "win.zoom-in"));
-        amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "win.zoom-out"));
-        amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "win.zoom-default"));
-        amtk_gmenu_append_section (menu, NULL, section);
-
-        g_object_unref (factory);
-        g_menu_freeze (menu);
-
-        return G_MENU_MODEL (menu);
-}
-
-static GMenuModel *
-create_window_menu_plus_app_menu (void)
+create_menu (void)
 {
         GMenu *menu;
         GMenu *section;
@@ -529,12 +498,24 @@ create_window_menu_plus_app_menu (void)
 
         section = g_menu_new ();
         amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "app.preferences"));
-        amtk_gmenu_append_section (menu, NULL, section);
-
-        section = g_menu_new ();
         amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "win.shortcuts-window"));
         amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "app.help"));
         amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "app.about"));
+        /* Keep the Quit menu item. The GNOME goal recommends to remove it:
+         * https://gitlab.gnome.org/GNOME/Initiatives/wikis/App-Menu-Retirement
+         * “There is no need for the Quit menu item and the recommendation is to
+         * remove it from all locations.”
+         * In Devhelp, there *is* a need for the Quit menu item: after
+         * installing/uninstalling books on the filesystem, it may be necessary
+         * to restart Devhelp because the file monitoring is not perfect, see
+         * the class description of DhBookListDirectory. Instead of closing the
+         * Devhelp windows one by one, it's simpler to quit the whole
+         * application at once. But this can be fixed by adding a “reload books”
+         * action.
+         * Another use-case with the Quit menu item is when the app bugs, just
+         * restarting the app will most probably fix the problem (and then the
+         * user needs to avoid repeating the actions that make the app to bug).
+         */
         amtk_gmenu_append_item (section, amtk_factory_create_gmenu_item (factory, "app.quit"));
         amtk_gmenu_append_section (menu, NULL, section);
 
@@ -552,12 +533,11 @@ init_header_bar (DhWindow *window)
         GtkStyleContext *style_context;
         GtkWidget *back_button;
         GtkWidget *forward_button;
-        GtkApplication *app;
-        GMenuModel *window_menu;
+        GMenuModel *menu;
         GtkWidget *new_tab_button;
 
         g_assert (priv->header_bar == NULL);
-        g_assert (priv->window_menu_button == NULL);
+        g_assert (priv->menu_button == NULL);
 
         priv->header_bar = GTK_HEADER_BAR (gtk_header_bar_new ());
         gtk_header_bar_set_show_close_button (priv->header_bar, TRUE);
@@ -580,18 +560,13 @@ init_header_bar (DhWindow *window)
         gtk_header_bar_pack_start (priv->header_bar, back_forward_hgrid);
 
         /* Menu */
-        priv->window_menu_button = GTK_MENU_BUTTON (gtk_menu_button_new ());
-        gtk_menu_button_set_direction (priv->window_menu_button, GTK_ARROW_NONE);
-        gtk_header_bar_pack_end (priv->header_bar, GTK_WIDGET (priv->window_menu_button));
+        priv->menu_button = GTK_MENU_BUTTON (gtk_menu_button_new ());
+        gtk_menu_button_set_direction (priv->menu_button, GTK_ARROW_NONE);
+        gtk_header_bar_pack_end (priv->header_bar, GTK_WIDGET (priv->menu_button));
 
-        app = GTK_APPLICATION (g_application_get_default ());
-        if (gtk_application_prefers_app_menu (app))
-                window_menu = create_window_menu_simple ();
-        else
-                window_menu = create_window_menu_plus_app_menu ();
-
-        gtk_menu_button_set_menu_model (priv->window_menu_button, window_menu);
-        g_object_unref (window_menu);
+        menu = create_menu ();
+        gtk_menu_button_set_menu_model (priv->menu_button, menu);
+        g_object_unref (menu);
 
         /* New tab button */
         new_tab_button = gtk_button_new_from_icon_name ("tab-new-symbolic", GTK_ICON_SIZE_BUTTON);
